#
#  Specific system configuration settings for desktop
#
#  flake.nix
#   ├─ ./hosts
#   │   └─ ./laptop
#   │        ├─ default.nix *
#   │        └─ hardware-configuration.nix       
#   └─ ./modules
#       ├─ ./desktop
#       │   └─ ./hyprland
#       │       └─ hyprland.nix
#       ├─ ./modules
#       │   └─ ./programs
#       │       └─ waybar.nix
#       └─ ./hardware
#           └─ default.nix
#

{ config, nixpkgs, pkgs, user, lib, ... }:

{
  imports =                                                         # For now, if applying to other system, swap files
    [(import ./hardware-configuration.nix)] ++                      # Current system hardware config @ /etc/nixos/hardware-configuration.nix
    [(import ../../modules/wm/sway/default.nix)] ++         # Window Manager
    (import ../../modules/wm/virtualisation) ++             # libvirt + Docker
    [(import ../../modules/wm/virtualisation/kvm-amd.nix)] ++   # kvm module options
    (import ../../modules/hardware);                             # Hardware devices

  boot = {                                  # Boot options
    kernelPackages = pkgs.linuxPackages_latest;

    loader = {                              # EFI Boot
      systemd-boot.enable = lib.mkForce false;
      efi = {
        canTouchEfiVariables = true;
        efiSysMountPoint = "/boot";
      };
      timeout = 1;                          # Grub auto select time
    };

    lanzaboote = {
        enable = true;
        pkiBundle = "/etc/secureboot";
    };
  };

#  hardware.sane = {                           # Used for scanning with Xsane
#    enable = false;
#    extraBackends = [ pkgs.sane-airscan ];
#  };
#  hardware = {
#    nitrokey.enable = true;
#  };

#  environment = {
#    systemPackages = with pkgs; [
##      simple-scan
##       intel-media-driver
##       alacritty
#    ];
#  };

  services = {
    #auto-cpufreq.enable = true;
    blueman.enable = true;
    printing = {                            # Printing and drivers for TS5300
      enable = true;
      drivers = [ pkgs.gutenprint ];
    };
    avahi = {                               # Needed to find wireless printer
      enable = true;
      nssmdns4 = true;
      publish = {                           # Needed for detecting the scanner
        enable = true;
        addresses = true;
        userServices = true;
      };
    };
  };

}
